# findmypy - Apple FindMy Python Library

Library to use Apple's FindMy Api.

This Library is heavily inspired by [pyicloud](https://github.com/picklepete/pyicloud) because it was programmed to replace it for device tracking in [home-assistant](https://github.com/home-assistant/core) because of continuus Emails about iCloud-Logins.

Code uses also parts of [PHP-FindMyiPhone](https://github.com/albeebe/PHP-FindMyiPhone) and the [openHAB iCloud-Binding](https://github.com/openhab/openhab-addons/tree/main/bundles/org.openhab.binding.icloud)
